@@ -23,6 +23,9 @@ from collections import Counter
 import glob
 from enum import Enum
 import pkg_resources
+import os
+from os.path import exists
+import zipfile
 
 import numpy as np
 import numpy.typing as npt
@@ -35,8 +38,6 @@ from gwr_inversion import gwr
 from mpmath import mp
 from typing import Tuple
 
-
-
 EPS_T = 1e-15
 MAX_ITR = 100
 
@@ -809,23 +810,70 @@ def influence_tables(
 
     return (tD, pDs)
 
-def zip_check_ecl(deck: str, to_zip: bool = True):
-    """ Performs a recursive ECL deck zip/check
+def zip_check_sim_deck(files2scrape = [], tozip = True, console_summary = True):
+    """ Performs recursive ECL/IX deck zip/check
         Crawls through all INCLUDE files in a deck, including an unlimited number of subdirectories and nested INCLUDE references, 
-        and (a) checks that all include files exist, then optionally (b) creates a zip file of all required files
+        and (a) checks that all include files exist, then optionally (b) creates a zip file of all associated files
         It does NOT zip any files that are in a higher directory than the .DATA file, but it does flag any such files so users can manually include them
         
-        deck: File name including extension of the base ECLIPSE data file
-        zipfiles: Boolean flag that controls whether a zip archive of the .DATA file and all nested INCLUDE files is created
+        Run in directory containing the simulation DATA or AFI files (or change directory to there)
+        Select one or more decks by their index number when prompted, then follow instructions
+        
+        files2scrape: A list of file names to scrape. These must be .DATA and/or .AFI files
+                      If no (or empty) list is passed, then user will be prompted to select one or more from the files existing in the current directory
+        tozip: Controls whether all files will be zipped, or whether a check that all files exist is all that is performed.
+               If no (or empty) files2scrape list was passed, then user will be prompted for their choice no matter what was specified.   
+               
+        console_summary: Controls whether summary results are returned to console or not
+                         If False, will return a list of missing INCLUDE files. A zero length list would indicate no missing files.
     """
 
-    file2scrape = deck
+    def get_loc(mask):
+        input_files = []
+        
+        for files in mask:
     
-    # Load base deck into list
-    lines = tuple(open(file2scrape, 'r'))
+            for file in glob.glob(files.upper()): # Grab a list of all the files in the directory with file mask
+                input_files.append(file)
+            for file in glob.glob(files.lower()): # In case lowercase extension used
+                input_files.append(file)
+        input_files = list(set(input_files)) # In case duplicated file names due to checking upper and lower case
+        
+        if len(input_files) == 0:
+            print( 'No '+mask+' files exist in this directory - Terminating script')
+            sys.exit()
     
-    full_filenames = [file2scrape]   
-    parent_filenames = [file2scrape]
+        print(' ')
+        
+        input_files.sort()
+        
+        table = []
+        header=['Index', 'File Name']  # Print list of options to select from
+        for i in range(len(input_files)):
+            table.append([i,input_files[i]])
+        print(tabulate(table,headers=header))    
+        print(' ')
+        file_idx = input('Please choose index(s) of file to parse separated by commas (0 - '+str(len(input_files)-1)+') :')
+        file_idxs = [int(x) for x in file_idx.split(',')]
+    
+        if not all(item in [i for i in range(0, len(input_files))] for item in file_idxs):
+            print(' ')
+            print( 'Index entered outside range permitted - Terminating script')
+            sys.exit()
+        
+        in_files =  [input_files[x] for x in file_idxs]
+        return in_files
+    
+    types = ('*.DATA', '*.afi')
+    if len(files2scrape) == 0:
+        files2scrape = get_loc(types)
+        tozip = True
+        method = input('Zip or Check files? (Z/c): ')
+        if method.upper()=='C':
+            tozip = False
+    
+    files2scrape = [x for x in files2scrape]   
+    parent_filenames = [x for x in files2scrape] 
     missing_parents = []
     # Start stepping through, looking for INCLUDE file statements
     get_include = False
@@ -836,96 +884,133 @@ def zip_check_ecl(deck: str, to_zip: bool = True):
     missing = []
     endfound = False
     while not got_all:
-        print('Scanning through: '+full_filenames[nscraped])
+        if console_summary:
+            print('Scanning through: '+files2scrape[nscraped])
+                    
+        # Load file into list
+        try:
+            lines = list(tuple(open(files2scrape[nscraped], 'r')))
+
+        except:
+            if not exists(files2scrape[nscraped]):
+                missing.append(files2scrape[nscraped])
+                missing_parents.append(parent_filenames[nscraped])
+                nscraped += 1
+                got_next = True
+                if len(files2scrape) == nscraped:
+                    got_all = True
+            continue
+
         for line in lines:
-            if endfound:
-                continue
-            if line[:3]== '--': # Skip all comments
+            line = line.strip() # Remove leading and trailing spaces
+            if line[:3]== '--' or line[:1]=='#': # Skip all comments
                 continue
             if line[:4]== 'END': # Skip everything after an END command
                 endfound = True
                 continue
-            if line.strip().upper()[:7]=='INCLUDE':
+            if line.upper()[:7]=='INCLUDE':
                 get_include = True
+                if '{' in line and 'TYPE' in line.upper(): # Must be IX file
+                    line = line.split('{')[0] # Remove trailing information for IX
+                    line = line.split()[1] # Get filename
+                    line = line.replace('"','') # Remove double inverted commas
+                    line=line.strip()
+                    if line not in files2scrape:
+                        files2scrape.append(line)   
+                        parent_filenames.append(files2scrape[nscraped])
+                        if '..' in line:
+                            higher_dir = True
+                    get_include = False
                 continue
             if get_include:
                 try:
-                    line = line.split('--')[0] # Remove trailing comments
+                    line = line.split('--')[0] # Remove trailing comments in ECL
                 except:
                     pass
-                line = line.strip() # Remove trailing spaces
-                if line[-1] == '/': # A data line - grab it
-                    line = line[:-1]
+                line = line.strip() # Remove trailing spaces that may remain after removing trailing comments
+                    
+                if '/' in line: # A data line - grab it
+                    idx = line.rfind('/') # Find index of last '/' instance 
+                    line = line[:idx]
                     line = line.replace('"','') # Remove double inverted commas
                     line = line.replace("'",'') # Remove single inverted commas
                     line = line.strip() # Remove leading and trailing spaces
                 
-                    if line not in full_filenames:
-                        full_filenames.append(line)   
-                        parent_filenames.append(full_filenames[nscraped])
+                    if line not in files2scrape:
+                        files2scrape.append(line)   
+                        parent_filenames.append(files2scrape[nscraped])
                         if '..' in line:
                             higher_dir = True
-    
                 get_include = False
+        got_next = True
+                
         # Finished scraping a file - are there any left?
-        nscraped += 1
-        if len(full_filenames) == nscraped:
+        if len(files2scrape) == nscraped:
             got_all = True
-        else:
-            got_next = False
-            while not got_next:
-                try:
-                    lines = tuple(open(full_filenames[nscraped], 'r'))
-                    got_next = True
-                except:
-                    missing.append(full_filenames[nscraped])
-                    missing_parents.append(parent_filenames[nscraped])
-                    nscraped += 1
-                    if len(full_filenames) == nscraped:
-                        got_all = True
-                        got_next = True
-    
+            continue
+            
+        nscraped += 1
+        
     if len(missing)>0:
-        print('\n****** MISSING FILES ******\n')
-        for f, file in enumerate(missing):
-            print(file, 'from', missing_parents[f])
+        if console_summary:
+            print('\n****** MISSING FILES ******\n')
+            for f, file in enumerate(missing):
+                print(file, 'from', missing_parents[f])
     
     higher_files = []
-    if not to_zip:
+    if not tozip:
         if len(missing) == 0:
-            print('\nALL INCLUDE FILES FOUND\n')
-            for file in full_filenames:
+            if console_summary:
+                print('\nALL INCLUDE FILES FOUND\n')
+            for file in files2scrape:
                 if '..' in file:
                     higher_files.append(file)
-            print('\n********** WARNING: Some INCLUDE files in a parent directory **********')
-            for file in higher_files:
-                print(file)
-            print('\nThese would need to be added manually to a zip file')
+            if len(higher_files) > 0:
+                if console_summary:
+                    print('\n********** WARNING: Some INCLUDE files in a parent directory **********')
+                    for file in higher_files:
+                            print(file)
+                    print('\nThese would need to be added manually to a zip file')
     
-    if to_zip:
-        print('\n'+str(len(full_filenames))+' files to zip')
+    if tozip:
+        if console_summary:
+            print('\n'+str(len(files2scrape))+' files to zip')
         if len(missing)>0:
-            cont = input('Continue to zip even with missing files? (Y/n): ')
-            if cont.upper() =='N':
-                sys.exit()
-        lista_files = full_filenames
-        with zipfile.ZipFile(lista_files[0][:-5]+'.zip', 'w') as zipMe:        
+            if console_summary:
+                cont = input('Continue to zip even with missing files? (Y/n): ')
+                if cont.upper() =='N':
+                    sys.exit()
+        lista_files = files2scrape
+        dotindex = ''.join(lista_files[0]).rindex('.')
+        zipname = lista_files[0][:dotindex]+'.zip'
+        with zipfile.ZipFile(zipname, 'w') as zipMe:        
             for f, file in enumerate(lista_files):
-                print('Zipping '+str(f+1)+' of '+str(nscraped)+': '+file)
+                if console_summary:
+                    print('Zipping '+str(f+1)+' of '+str(nscraped)+': '+file)
                 try:
                     zipMe.write(file, compress_type=zipfile.ZIP_DEFLATED)
                 except:
-                    print('\nSkipping '+file+', Not found\n' )
+                    if console_summary:
+                        print('\nSkipping '+file+', Not found\n' )
             
-        print('\n'+'Finished - Zip File Created: '+lista_files[0][:-5]+'.zip')
+        if console_summary:
+            print('\n'+'Finished - Zip File Created: '+zipname)
         if higher_dir:
             for file in lista_files:
                 if '..' in file:
                     higher_files.append(file)
-            print('\n********** WARNING: Files in parent directory(s) not zipped **********')
-            for file in higher_files:
-                print(file)
-            print('\nPlease add these manually to the zip file')
+            if console_summary:
+                print('\n********** WARNING: Files in parent directory(s) not zipped **********')
+                for file in higher_files:
+                    print(file)
+                print('\nPlease add these manually to the zip file')
+
+    if not console_summary:
+        return missing
+    else:
+        return
+                
+    
             
 def rr_solver(
     zi: np.ndarray, ki: np.ndarray
